@@ -3,11 +3,11 @@ package My::Module::Build;
 use strict;
 use warnings;
 
-use Module::Build;
-our @ISA = qw{ Module::Build };
+use base qw{ Module::Build };
 
 use Carp;
 
+
 sub ACTION_authortest {
     my ( $self ) = @_;		# Arguments unused
 
@@ -20,17 +20,6 @@ sub ACTION_authortest {
     return;
 }
 
-sub harness_switches {
-    my ( $self ) = @_;
-    my @res = $self->SUPER::harness_switches();
-    foreach ( @res ) {
-	'-MDevel::Cover' eq $_
-	    or next;
-	$_ .= '=-db,cover_db,-ignore,inc/';
-    }
-    return @res;
-}
-
 1;
 
 __END__
@@ -80,8 +69,7 @@ C<--test_files> argument.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-Win32API-File-Time/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -89,7 +77,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, 2016-2017, 2019-2021 Thomas R. Wyant, III
+Copyright (C) 2009-2010, 2016 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
