@@ -50,45 +50,12 @@ supply of tuits.
 
 =cut
 
-#	Modifications:
-
-# 0.001	13-May-2004	T. R. Wyant
-#		Initial version.
-# 0.002	02-Oct-2004	T. R. Wyant
-#		No code changes. Add the readme file to the manifest,
-#		and add the dependencies to Makefile.PL, since they
-#		really _should_ be there, and Active State is
-#		complaining about them missing.
-# 0.003	17-Dec-2004	T. R. Wyant
-#		Reimplement time conversion. Also modified the self-
-#		test to use a scratch file for the date modification
-#		portion of the test.
-# 0.003_01 28-Dec-2004	T. R. Wyant
-#		Close handles after use. In case of error, preserve
-#		the windows error around the close.
-# 0.004	13-Jan-2005	T. R. Wyant
-#		Fix export tags.
-#		Tweak "Bugs" section to more accurately represent what
-#			I think is going on.
-#		Release to CPAN.
-# 0.004_01 28-Apr-2005	T. R. Wyant
-#		Assert FILE_FLAG_BACKUP_SEMANTICS when reading times,
-#			so that it works for directories under XP and
-#			2003 server.
-#		Centralize code to close handles on error.
-# 0.004_02 04-May-2005	T. R. Wyant
-#		Document behaviour of FAT (and change test to
-#		accomodate.
-# 0.005 04-May-2005	T. R. Wyant
-#		Release to CPAN.
+package Win32API::File::Time;
 
 use strict;
 use warnings;
 
-package Win32API::File::Time;
-
 use base qw{Exporter};
-use vars qw{@EXPORT_OK %EXPORT_TAGS $VERSION};
 use vars qw{
 	$FileTimeToSystemTime
 	$FileTimeToLocalFileTime
@@ -103,10 +70,10 @@ use Time::Local;
 use Win32::API;
 use Win32API::File qw{:ALL};
 
-$VERSION = '0.006';
+our $VERSION = '0.007';
 
-@EXPORT_OK = qw{GetFileTime SetFileTime utime};
-%EXPORT_TAGS = (
+our @EXPORT_OK = qw{GetFileTime SetFileTime utime};
+our %EXPORT_TAGS = (
     all => [@EXPORT_OK],
     win => [qw{GetFileTime SetFileTime}],
     );
@@ -180,11 +147,10 @@ error encountered.
 
 =cut
 
-sub utime {
-my $atime = shift;
-my $mtime = shift;
+sub utime {	## no critic (ProhibitBuiltinHomonyms)
+my ( $atime, $mtime, @args ) = @_;
 my $num = 0;
-foreach my $fn (@_) {
+foreach my $fn (@args) {
     SetFileTime ($fn, $atime, $mtime) and $num++;
     }
 return $num;
@@ -204,7 +170,7 @@ sub _close_handle {
 my $fh = shift;
 my $err = Win32::GetLastError ();
 CloseHandle ($fh);
-$^E = $err;
+$^E = $err;	## no critic (RequireLocalizedPunctuationVars)
 return;
 }
 
@@ -223,20 +189,21 @@ return;
 #	results of the stat () function.
 
 sub _filetime_to_perltime {
+my @args = @_;
 my @result;
 $FileTimeToSystemTime ||= _map (
 	'KERNEL32', 'FileTimeToSystemTime', [qw{P P}], 'I');
 $FileTimeToLocalFileTime ||= _map (
 	'KERNEL32', 'FileTimeToLocalFileTime', [qw{P P}], 'I');
 my $st = pack 'ssssssss', 0, 0, 0, 0, 0, 0, 0, 0;
-foreach my $ft (@_) {
-    my ($low, $high) = unpack 'LL', $ft;
+foreach my $ft (@args) {
+    my (undef, $high) = unpack 'LL', $ft;	# $low unused
     $high or do {
 	push @result, undef;
 	next;
 	};
     my $lf = $ft;	# Just to get the space allocated.
-    $FileTimeToLocalFileTime->Call ($ft, $lf) &&
+    $FileTimeToLocalFileTime->Call ($ft, $lf) and
 	$FileTimeToSystemTime->Call ($lf, $st) or do {
 	push @result, undef;
 	next;
@@ -261,7 +228,7 @@ sub _get_handle {
 my $fn = shift;
 my $write = shift;
 
-${^WIDE_SYSTEM_CALLS} ?
+my $handle = ${^WIDE_SYSTEM_CALLS} ?
     CreateFileW ($fn,
 	($write ? FILE_WRITE_ATTRIBUTES : FILE_READ_ATTRIBUTES),
 	($write ? FILE_SHARE_WRITE | FILE_SHARE_READ : FILE_SHARE_READ),
@@ -279,9 +246,10 @@ ${^WIDE_SYSTEM_CALLS} ?
 	0,
 	)
   or do {
-    $^E = Win32::GetLastError ();
+    $^E = Win32::GetLastError ();	## no critic (RequireLocalizedPunctuationVars)
     return;
     };
+return $handle;
 }
 
 
@@ -303,6 +271,7 @@ return Win32::API->new (@_) ||
 #	the one used in _filetime_to_perltime.
 
 sub _perltime_to_filetime {
+    my @args = @_;
 my @result;
 $SystemTimeToFileTime ||= _map (
 	'KERNEL32', 'SystemTimeToFileTime', [qw{P P}], 'I');
@@ -310,7 +279,7 @@ $LocalFileTimeToFileTime ||= _map (
 	'KERNEL32', 'LocalFileTimeToFileTime', [qw{P P}], 'I');
 my $zero = pack 'LL', 0, 0;	# To get a quadword zero.
 my ($ft, $lf) = ($zero, $zero);	# To get the space allocated.
-foreach my $pt (@_) {
+foreach my $pt (@args) {
     if (defined $pt) {
 	my @tm = localtime ($pt);
 	my $st = pack 'ssssssss', $tm[5] + 1900, $tm[4] + 1, 0,
@@ -325,43 +294,24 @@ foreach my $pt (@_) {
 return wantarray ? @result : $result[0];
 }
 
+1;
+
+__END__
+
 =back
 
-=head1 HISTORY
-
- 0.001 Initial release
- 0.002 Correct MANIFEST and Makefile.PL dependencies.
-       Tweak documentation. No code changes.
- 0.003 Correct time conversion.
-       Modify test to not change own date.
- 0.004 Close handles after use. Thanks to Chris
-           Camejo for pointing out the leak.
-       Fix export tags to agree with docs.
-       Tweak "BUGS" documentation.
- 0.005 Assert FILE_FLAG_BACKUP_SEMANTICS when reading
-           times, so that it works for directories
-           under XP and 2003 server. Thanks to Leigh
-           Power for pointing out the problem and
-           suggesting the solution.
-       Document FAT, and accomodate it in self-test.
-           Thanks again, Leigh.
-       Centralize code to close handles on error.
- 0.006 T. R. Wyant
-       Re-layout kit, add POD tests.
-
 =head1 BUGS
 
-As implemented, GetFileTime () constitutes an access, and
-therefore updates the access time.
+As implemented, C<GetFileTime()> constitutes an access, and therefore
+updates the access time.
 
-The stat () builtin, on the other hand, doesn't report
-an access time change even after GetFileTime () has been
-used. In fact, it looks to me very much like stat () reports
-the modification time in element [8] of the list, but I
-find this nowhere documented.
+The C<stat()> builtin, on the other hand, doesn't report an access time
+change even after C<GetFileTime()> has been used. In fact, it looks to
+me very much like C<stat()> reports the modification time in element [8]
+of the list, but I find this nowhere documented.
 
 FAT file time resolution is 2 seconds at best, as documented
-at F<http://support.microsoft.com/default.aspx?scid=kb;en-us;127830>.
+at L<http://support.microsoft.com/default.aspx?scid=kb;en-us;127830>.
 Access time resolution seems to be to the nearest day.
 
 =head1 ACKNOWLEDGMENTS
@@ -385,25 +335,25 @@ who worked on times.cc in the Cygwin core. This is the B<only>
 implementation of utime I could find which did what B<I> wanted
 it to do.
 
-
 =head1 AUTHOR
 
 Thomas R. Wyant, III (F<Thomas.R.Wyant-III@usa.dupont.com>)
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2004, 2005 by
-E. I. DuPont de Nemours and Company, Inc.
-All rights reserved.
-
-Changes since version 0.005 copyright 2007 by Thomas R. Wyant, III.  All
+Copyright (C) 2004-2005 by E. I. DuPont de Nemours and Company, Inc. All
 rights reserved.
 
-=head1 LICENSE
+Copyright (C) 2007, 2010, 2016 by Thomas R. Wyant, III
 
-This module is free software; you can use it, redistribute it and/or
-modify it under the same terms as Perl itself. Please see
-L<http://perldoc.perl.org/index-license.html> for current licenses.
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl 5.10.0. For more details, see the full text
+of the licenses in the directory LICENSES.
+
+This program is distributed in the hope that it will be useful, but
+without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
 
 =cut
 
+# ex: set textwidth=72 :
